@@ -2,27 +2,25 @@
 An experimental support for curvilinear grid.
 """
 
+import functools
 
 # TODO :
+# see if tick_iterator method can be simplified by reusing the parent method.
 
-# *. see if tick_iterator method can be simplified by reusing the parent method.
-
-from itertools import chain
-from .grid_finder import GridFinder
-
-from  .axislines import AxisArtistHelper, GridHelperBase
-from  .axis_artist import AxisArtist
-from matplotlib.transforms import Affine2D, IdentityTransform
 import numpy as np
 
-
+from matplotlib.transforms import Affine2D, IdentityTransform
 from . import grid_helper_curvelinear
+from .axislines import AxisArtistHelper, GridHelperBase
+from .axis_artist import AxisArtist
+from .grid_finder import GridFinder
+
 
 class FloatingAxisArtistHelper(grid_helper_curvelinear.FloatingAxisArtistHelper):
     pass
 
-class FixedAxisArtistHelper(grid_helper_curvelinear.FloatingAxisArtistHelper):
 
+class FixedAxisArtistHelper(grid_helper_curvelinear.FloatingAxisArtistHelper):
 
     def __init__(self, grid_helper, side, nth_coord_ticks=None):
         """
@@ -31,11 +29,7 @@ class FixedAxisArtistHelper(grid_helper_curvelinear.FloatingAxisArtistHelper):
         """
 
         value, nth_coord = grid_helper.get_data_boundary(side) # return v= 0 , nth=1, extremes of the other coordinate.
-        super(FixedAxisArtistHelper, self).__init__(grid_helper,
-                                                    nth_coord,
-                                                    value,
-                                                    axis_direction=side,
-                                                    )
+        super().__init__(grid_helper, nth_coord, value, axis_direction=side)
         #self.grid_helper = grid_helper
         if nth_coord_ticks is None:
             nth_coord_ticks = nth_coord
@@ -72,8 +66,7 @@ class FixedAxisArtistHelper(grid_helper_curvelinear.FloatingAxisArtistHelper):
         trans_passingthrough_point = axes.transData + axes.transAxes.inverted()
         p = trans_passingthrough_point.transform_point([xx1[0], yy1[0]])
 
-
-        if (0. <= p[0] <= 1.) and (0. <= p[1] <= 1.):
+        if 0 <= p[0] <= 1 and 0 <= p[1] <= 1:
             xx1c, yy1c = axes.transData.transform_point([xx1[0], yy1[0]])
             xx2, yy2 = grid_finder.transform_xy([xx0+dxx], [yy0+dyy])
             xx2c, yy2c = axes.transData.transform_point([xx2[0], yy2[0]])
@@ -136,12 +129,12 @@ class FixedAxisArtistHelper(grid_helper_curvelinear.FloatingAxisArtistHelper):
 
             xx1, yy1 = transform_xy(xx0, yy0)
 
-            xx00 = xx0.copy()
+            xx00 = xx0.astype(float, copy=True)
             xx00[xx0+dx>xmax] -= dx
             xx1a, yy1a = transform_xy(xx00, yy0)
             xx1b, yy1b = transform_xy(xx00+dx, yy0)
 
-            yy00 = yy0.copy()
+            yy00 = yy0.astype(float, copy=True)
             yy00[yy0+dy>ymax] -= dy
             xx2a, yy2a = transform_xy(xx0, yy00)
             xx2b, yy2b = transform_xy(xx0, yy00+dy)
@@ -157,12 +150,12 @@ class FixedAxisArtistHelper(grid_helper_curvelinear.FloatingAxisArtistHelper):
             xx1, yy1 = transform_xy(xx0, yy0)
 
 
-            yy00 = yy0.copy()
+            yy00 = yy0.astype(float, copy=True)
             yy00[yy0+dy>ymax] -= dy
             xx1a, yy1a = transform_xy(xx0, yy00)
             xx1b, yy1b = transform_xy(xx0, yy00+dy)
 
-            xx00 = xx0.copy()
+            xx00 = xx0.astype(float, copy=True)
             xx00[xx0+dx>xmax] -= dx
             xx2a, yy2a = transform_xy(xx00, yy0)
             xx2b, yy2b = transform_xy(xx00+dx, yy0)
@@ -175,25 +168,18 @@ class FixedAxisArtistHelper(grid_helper_curvelinear.FloatingAxisArtistHelper):
             dd = np.arctan2(yy1b-yy1a, xx1b-xx1a) # angle normal
             dd2 = np.arctan2(yy2b-yy2a, xx2b-xx2a) # angle tangent
             mm = ((yy1b-yy1a)==0.) & ((xx1b-xx1a)==0.) # mask where dd1 is not defined
-            dd[mm] = dd2[mm]+3.14159/2.
+            dd[mm] = dd2[mm] + np.pi / 2
 
-            #dd += 3.14159
+            #dd += np.pi
             #dd = np.arctan2(xx2-xx1, angle_tangent-yy1)
             trans_tick = self.get_tick_transform(axes)
             tr2ax = trans_tick + axes.transAxes.inverted()
             for x, y, d, d2, lab in zip(xx1, yy1, dd, dd2, labels):
                 c2 = tr2ax.transform_point((x, y))
                 delta=0.00001
-                if (0. -delta<= c2[0] <= 1.+delta) and \
-                       (0. -delta<= c2[1] <= 1.+delta):
-                    d1 = d/3.14159*180.
-                    d2 = d2/3.14159*180.
-                    #_mod = (d2-d1+180)%360
-                    #if _mod < 180:
-                    #    d1 += 180
-                    ##_div, _mod = divmod(d2-d1, 360)
+                if 0-delta <= c2[0] <= 1+delta and 0-delta <= c2[1] <= 1+delta:
+                    d1, d2 = np.rad2deg([d, d2])
                     yield [x, y], d1, d2, lab
-                    #, d2/3.14159*180.+da)
 
         return f1(), iter([])
 
@@ -210,7 +196,7 @@ class FixedAxisArtistHelper(grid_helper_curvelinear.FloatingAxisArtistHelper):
                     top=("lat_lines0", 1))[self._side]
 
         xx, yy = self.grid_info[k][v]
-        return Path(list(zip(xx, yy)))
+        return Path(np.column_stack([xx, yy]))
 
 
 
@@ -246,7 +232,7 @@ class GridHelperCurveLinear(grid_helper_curvelinear.GridHelperCurveLinear):
         objects which defines the transform and its inverse. The callables
         need take two arguments of array of source coordinates and
         should return two target coordinates:
-          e.g., x2, y2 = trans(x1, y1)
+        e.g., *x2, y2 = trans(x1, y1)*
         """
 
         self._old_values = None
@@ -254,12 +240,12 @@ class GridHelperCurveLinear(grid_helper_curvelinear.GridHelperCurveLinear):
         self._extremes = extremes
         extreme_finder = ExtremeFinderFixed(extremes)
 
-        super(GridHelperCurveLinear, self).__init__(aux_trans,
-                                                    extreme_finder,
-                                                    grid_locator1=grid_locator1,
-                                                    grid_locator2=grid_locator2,
-                                                    tick_formatter1=tick_formatter1,
-                                                    tick_formatter2=tick_formatter2)
+        super().__init__(aux_trans,
+                         extreme_finder,
+                         grid_locator1=grid_locator1,
+                         grid_locator2=grid_locator2,
+                         tick_formatter1=tick_formatter1,
+                         tick_formatter2=tick_formatter2)
 
 
     # def update_grid_finder(self, aux_trans=None, **kw):
@@ -519,19 +505,12 @@ class FloatingAxesBase(object):
         self.set_ylim(ymin-dy, ymax+dy)
 
 
-
-_floatingaxes_classes = {}
-
+@functools.lru_cache(None)
 def floatingaxes_class_factory(axes_class):
+    return type("Floating %s" % axes_class.__name__,
+                (FloatingAxesBase, axes_class),
+                {'_axes_class_floating': axes_class})
 
-    new_class = _floatingaxes_classes.get(axes_class)
-    if new_class is None:
-        new_class = type("Floating %s" % (axes_class.__name__),
-                         (FloatingAxesBase, axes_class),
-                         {'_axes_class_floating': axes_class})
-        _floatingaxes_classes[axes_class] = new_class
-
-    return new_class
 
 from .axislines import Axes
 from mpl_toolkits.axes_grid1.parasite_axes import host_axes_class_factory
@@ -541,181 +520,3 @@ FloatingAxes = floatingaxes_class_factory(host_axes_class_factory(Axes))
 
 import matplotlib.axes as maxes
 FloatingSubplot = maxes.subplot_class_factory(FloatingAxes)
-
-# def test(fig):
-#     from mpl_toolkits.axes_grid.axislines import Subplot
-#     ax = Subplot(fig, 111)
-
-#     fig.add_subplot(ax)
-
-#     plt.draw()
-
-
-def curvelinear_test3(fig):
-    """
-    polar projection, but in a rectangular box.
-    """
-    global ax1, axis
-    import numpy as np
-    from . import angle_helper
-    from matplotlib.projections import PolarAxes
-
-    # PolarAxes.PolarTransform takes radian. However, we want our coordinate
-    # system in degree
-    tr = Affine2D().scale(np.pi/180., 1.) + PolarAxes.PolarTransform()
-
-    # polar projection, which involves cycle, and also has limits in
-    # its coordinates, needs a special method to find the extremes
-    # (min, max of the coordinate within the view).
-
-
-    grid_locator1 = angle_helper.LocatorDMS(15)
-    # Find a grid values appropriate for the coordinate (degree,
-    # minute, second).
-
-    tick_formatter1 = angle_helper.FormatterDMS()
-    # And also uses an appropriate formatter.  Note that,the
-    # acceptable Locator and Formatter class is a bit different than
-    # that of mpl's, and you cannot directly use mpl's Locator and
-    # Formatter here (but may be possible in the future).
-
-    from .grid_finder import FixedLocator
-    grid_locator2 = FixedLocator([2, 4, 6, 8, 10])
-
-
-    grid_helper = GridHelperCurveLinear(tr,
-                                        extremes=(0, 360, 10, 3),
-                                        grid_locator1=grid_locator1,
-                                        grid_locator2=grid_locator2,
-                                        tick_formatter1=tick_formatter1,
-                                        tick_formatter2=None,
-                                        )
-
-    ax1 = FloatingSubplot(fig, 111, grid_helper=grid_helper)
-
-
-    #ax1.axis["top"].set_visible(False)
-    #ax1.axis["bottom"].major_ticklabels.set_axis_direction("top")
-
-    fig.add_subplot(ax1)
-
-
-    #ax1.grid(True)
-
-
-    r_scale = 10.
-    tr2 = Affine2D().scale(1., 1./r_scale) + tr
-    grid_locator2 = FixedLocator([30, 60, 90])
-    grid_helper2 = GridHelperCurveLinear(tr2,
-                                        extremes=(0, 360,
-                                                  10.*r_scale, 3.*r_scale),
-                                        grid_locator2=grid_locator2,
-                                        )
-
-    ax1.axis["right"] = axis = grid_helper2.new_fixed_axis("right", axes=ax1)
-
-    ax1.axis["left"].label.set_text("Test 1")
-    ax1.axis["right"].label.set_text("Test 2")
-
-
-    for an in [ "left", "right"]:
-        ax1.axis[an].set_visible(False)
-
-
-    #grid_helper2 = ax1.get_grid_helper()
-    ax1.axis["z"] = axis = grid_helper.new_floating_axis(1, 7,
-                                                         axes=ax1,
-                                                         axis_direction="bottom")
-    axis.toggle(all=True, label=True)
-    #axis.label.set_axis_direction("top")
-    axis.label.set_text("z = ?")
-    axis.label.set_visible(True)
-    axis.line.set_color("0.5")
-    #axis.label.set_visible(True)
-
-
-    ax2 = ax1.get_aux_axes(tr)
-
-    xx, yy = [67, 90, 75, 30], [2, 5, 8, 4]
-    ax2.scatter(xx, yy)
-    l, = ax2.plot(xx, yy, "k-")
-    l.set_clip_path(ax1.patch)
-
-
-def curvelinear_test4(fig):
-    """
-    polar projection, but in a rectangular box.
-    """
-    global ax1, axis
-    import numpy as np
-    from . import  angle_helper
-    from matplotlib.projections import PolarAxes
-
-    tr = Affine2D().scale(np.pi/180., 1.) + PolarAxes.PolarTransform()
-
-    grid_locator1 = angle_helper.LocatorDMS(5)
-    tick_formatter1 = angle_helper.FormatterDMS()
-
-    from .grid_finder import FixedLocator
-    grid_locator2 = FixedLocator([2, 4, 6, 8, 10])
-
-    grid_helper = GridHelperCurveLinear(tr,
-                                        extremes=(120, 30, 10, 0),
-                                        grid_locator1=grid_locator1,
-                                        grid_locator2=grid_locator2,
-                                        tick_formatter1=tick_formatter1,
-                                        tick_formatter2=None,
-                                        )
-
-    ax1 = FloatingSubplot(fig, 111, grid_helper=grid_helper)
-
-
-    #ax1.axis["top"].set_visible(False)
-    #ax1.axis["bottom"].major_ticklabels.set_axis_direction("top")
-
-    fig.add_subplot(ax1)
-
-
-    #ax1.grid(True)
-
-
-    ax1.axis["left"].label.set_text("Test 1")
-    ax1.axis["right"].label.set_text("Test 2")
-
-
-    for an in [ "top"]:
-        ax1.axis[an].set_visible(False)
-
-
-    #grid_helper2 = ax1.get_grid_helper()
-    ax1.axis["z"] = axis = grid_helper.new_floating_axis(1, 70,
-                                                         axes=ax1,
-                                                         axis_direction="bottom")
-    axis.toggle(all=True, label=True)
-    axis.label.set_axis_direction("top")
-    axis.label.set_text("z = ?")
-    axis.label.set_visible(True)
-    axis.line.set_color("0.5")
-    #axis.label.set_visible(True)
-
-
-    ax2 = ax1.get_aux_axes(tr)
-
-    xx, yy = [67, 90, 75, 30], [2, 5, 8, 4]
-    ax2.scatter(xx, yy)
-    l, = ax2.plot(xx, yy, "k-")
-    l.set_clip_path(ax1.patch)
-
-if __name__ == "__main__":
-    import matplotlib.pyplot as plt
-    fig = plt.figure(1, figsize=(5, 5))
-    fig.clf()
-
-    #test(fig)
-    #curvelinear_test1(fig)
-    curvelinear_test4(fig)
-
-    #plt.draw()
-    plt.show()
-
-
